jactorch.nn package
===================

.. automodule:: jactorch.nn
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   jactorch.nn.cnn
   jactorch.nn.gumbel_softmax
   jactorch.nn.losses
   jactorch.nn.neural_logic
   jactorch.nn.prroi_pool
   jactorch.nn.sync_batchnorm

Submodules
----------

jactorch.nn.container module
----------------------------

.. automodule:: jactorch.nn.container
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.embedding module
----------------------------

.. automodule:: jactorch.nn.embedding
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.functional module
-----------------------------

.. automodule:: jactorch.nn.functional
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.linear module
-------------------------

.. automodule:: jactorch.nn.linear
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.normalization module
--------------------------------

.. automodule:: jactorch.nn.normalization
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.probability module
------------------------------

.. automodule:: jactorch.nn.probability
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.quickaccess module
------------------------------

.. automodule:: jactorch.nn.quickaccess
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.residual module
---------------------------

.. automodule:: jactorch.nn.residual
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.rnn\_layers module
------------------------------

.. automodule:: jactorch.nn.rnn_layers
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.rnn\_utils module
-----------------------------

.. automodule:: jactorch.nn.rnn_utils
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.simple module
-------------------------

.. automodule:: jactorch.nn.simple
   :members:
   :undoc-members:
   :show-inheritance:

jactorch.nn.word\_embedding module
----------------------------------

.. automodule:: jactorch.nn.word_embedding
   :members:
   :undoc-members:
   :show-inheritance:
